@@ -25,7 +25,6 @@ safe_module_require_class('fs', 'application');
 safe_module_require_class('fs', 'lcr_rate');
 class Fs_lcr_carrier_class extends Safe_configurable_object_class
 {
-    private $_rates;
     private $_the_app;
     private $_sip_trunks = null;
     private $_distributor_lists = null; //Load Balancing list
@@ -60,48 +59,34 @@ class Fs_lcr_carrier_class extends Safe_configurable_object_class
         // Register aggregate objects
         $this->register_aggregate_object('rate', 
             array(
-                'name' => 'Carrier Rate',
+                'name' => 'Carrier Rates File',
                 'dynamic' => true,
-                'base_path' => $this->object_name() . '/rate',
                 /* Add some extra infos for config_manager create object */
                 'controller' => array(
                         'config_manager' => array(
-                                'custom_button' => array(
-                                        array(
-                                                'id' => 'upload_form',
-                                                'name' => 'Upload',
-                                                'type' => 'create',
-                                                'url'  => ''
-                                        ),
-                                        array(
-                                                'id' => 'download',
-                                                'name' => 'Download',
-                                                'type' => 'button',
-                                                'url'  =>''
-                                        ),
-                                )
+                                'summary_buttons' => 'edit[Edit]|download[Download]|Delete:confirm',
+                                'allow_create_button' => 'upload[Upload]'
                         ),
                 ),
                 'autoname' => true,
+                'popup_add_form' => true,
+                'file_def' => array(
+                    'file_type' => 'csv',
+                ),
                 'methods' => array(
-                        'create' => array(
-                                'name' => 'Create',
-                                'description' => 'Create a rate',
+                        'upload' => array(
+                                'name' => 'Upload',
+                                'description' => 'Upload a rates file',
                                 'request' => 'POST',
                         ),
-                        'retrieve' => array(
-                                'name' => 'Retrieve',
-                                'description' => 'Retrieve a rate',
+                        'download' => array(
+                                'name' => 'Download',
+                                'description' => 'Download a rates file',
                                 'request' => 'GET',
                         ),
-                        'update' => array(
-                                'name' => 'Update',
-                                'description' => 'Update a rate',
-                                'request' => 'POST',
-                        ),
                         'delete' => array(
                                 'name' => 'Delete',
-                                'description' => 'Delete a rate',
+                                'description' => 'Delete a rates file',
                                 'request' => 'POST',
                         ),
                 ),
@@ -166,8 +151,7 @@ class Fs_lcr_carrier_class extends Safe_configurable_object_class
      */
     public function carrier_rate()
     {
-        $this->_rates = $this->get_aggregate_objects('rate');
-        return $this->_rates;
+        return $this->get_aggregate_objects('rate');
     }
     public function carrier_trunk()
     {
@@ -189,8 +173,11 @@ class Fs_lcr_carrier_class extends Safe_configurable_object_class
      *
      * @return
      */
-    public function api_create_rate($name, $data=null) {
-        $rate = new Fs_lcr_rate_class($this->node(), $this->object_name().'/rate', $name);
+    public function api_create_rate($name=null, $data = null, &$output = null){
+        return $this->api_upload_rate($name, $data, $output);
+    }
+    public function api_upload_rate($name=null, $data = null, &$output = null){
+        $rate = new Fs_lcr_rate_class($this->node(), $this->object_name().'/rate', $name, $this);
         $rate->configure();
         if($data) {
             $rate->set_data_values($data);
@@ -205,9 +192,12 @@ class Fs_lcr_carrier_class extends Safe_configurable_object_class
      *
      * @return
      */
+    public function api_download_rate($name, $data=null) {
+        $rate = $this->api_retrieve_rate($name, $data);
+        return $rate->download();
+    }
     public function api_retrieve_rate($name, $data=null) {
-        $rates = $this->rates();
-        return $rates[$name];
+        return $this->get_aggregate_object('rate', $name);
     }
     /**
      * @brief
@@ -237,14 +227,19 @@ class Fs_lcr_carrier_class extends Safe_configurable_object_class
      * @return
      */
     public function api_delete_rate($name, $data=null, &$output = null) {
-        $rates = $this->rates();
-        if($rates[$name]) {
-            if($rates[$name]->can_dispose($output)) {
-                return $rates[$name]->dispose();
+        $rate = $this->api_retrieve_rate($name);
+        if($rate) {
+            if($rate->can_dispose($output)) {
+                return $rate->dispose();
             }
         }
         return false;
     }
-
+    public function new_fields(&$config_manager, $type)
+    {
+        $config_manager->add_upload_field('ratefile','Rates File','upload','',30,true);
+        $config_manager->set_field_rules('ratefile','required');
+        $config_manager->add_field('save', 'Save', 'hidden', 'save', 10);
+    }
 }
 ?>
