@@ -127,6 +127,11 @@ class Nsc_sipsecmon_blockedip extends Safe_CI_Controller
         $data['message_type'] = 'notice';
         $data['result'] = true;
         $data['action_url'] = base_url($this->router->fetch_class()). '/unblock/'.$blocked_ip;
+        $data['setting']['title'] = 'Processing ...';
+        $data['setting']['sec'] = '30';
+        $data['setting']['msg'] = 'Ooops ! Action time out...';
+        $data['setting']['label'] = 'Close';
+        $data['setting']['url'] = '';
         echo json_encode($data);
     }
     /**
@@ -140,6 +145,7 @@ class Nsc_sipsecmon_blockedip extends Safe_CI_Controller
         $data['page_title'] = 'SIP Security Monitor - Blocked IPs';
         //Unblock IP
         $res = $this->_sipsecmon->unblock_ip($blocked_ip);
+        sleep(1);
         if ($res) {
             //success
             //return redirect url
