@@ -726,18 +726,22 @@ function safe_var_dump($v)
 /**
  * Echo the debug backtrace
  */
-function safe_debug_info($display=true)
+function safe_debug_info($display=true, $bt = null)
 {
+    if(null == $bt) {
+        $bt = debug_backtrace();
+    }
     if($display){
         echo '<pre style="display: block; text-align: left; color: black; background-color: #D5D5D5; font-size: medium;">';
     }
-    foreach (debug_backtrace() as $k => $v) {
+    foreach ($bt as $k => $v) {
         if ($k) {
             $l = safe_debug_info_line($v, $k);
             if($display){
                 echo htmlentities($l);
+            }else{
+                error_log($l);
             }
-            error_log($l);
         }
     }
     if($display){
@@ -1026,6 +1030,7 @@ function Safe_format_xml($xml)
                         'message' => $errstr,
                         'file' => $errfile,
                         'line' => $errline,
+                        'bt' => debug_backtrace(), 
                         // Too much info - 'context' => $errcontext,
                         
                     );
@@ -1060,11 +1065,20 @@ function Safe_format_xml($xml)
                     echo '</tr>';
                     foreach ($safe_error_buffer as $error) {
                         foreach ($error as $k => $v) {
-                            echo '<tr>';
+                            echo '<tr style="text-align:left;">';
                             echo '<td class="mytablealt">' . $k . '</td>';
-                            if (is_array($v)) echo '<td><pre>' . print_r($v, TRUE) . '</pre></td>';
-                            else echo '<td>' . $v . '</td>';
+                            echo '<td>';
+                            if('bt' == $k) {
+                                safe_debug_info(true, $v);
+                            }else if (is_array($v)){
+                                echo '<pre>' . print_r($v, TRUE) . '</pre>';
+                            }else{
+                                echo $v;
+                            }
+                            echo '</td>';
                             echo '</tr>';
+                            if($error['bt']) {
+                            }
                         }
                         echo '<tr>';
                         echo '<td colspan=2 class="mytablesubheader"/>';
