@@ -37,6 +37,8 @@ class Safe_service_class extends Safe_module_class
     const SIGHUP = 'SIGHUP';
     /* Private data */
     private $_process_name;
+    /* protected */
+    protected $_run_dir = '/var/run';
     /* Functions */
     public function __construct($software, $name, $process_name = null)
     {
@@ -160,12 +162,12 @@ class Safe_service_class extends Safe_module_class
     }
     public function startup()
     {
-        $auto = $this->node()->is_service_auto($this->name());
+        $auto = $this->node()->is_service_auto($this->name(), $this->_process_name);
         return (true == $auto) ? Safe_service_class::STARTUP_AUTOMATIC : Safe_service_class::STARTUP_MANUAL;
     }
     public function set_startup($mode)
     {
-        return $this->node()->set_service_startup($this->name() , ($mode == Safe_service_class::STARTUP_AUTOMATIC));
+        return $this->node()->set_service_startup($this->name() , ($mode == Safe_service_class::STARTUP_AUTOMATIC), $this->_process_name);
     }
     public function stats()
     {
@@ -185,6 +187,17 @@ class Safe_service_class extends Safe_module_class
         return $this->node()->kill($this->name() , $signal, $this->_process_name);
     }
     public function allow_user_ctl()
+    {
+        $def = $this->property('allow_user_ctl', true);
+        if('true' === $def){
+            $def = true;
+        }
+        if('false' === $def){
+            $def = false;
+        }
+        return $def;
+    }
+    public function allow_dashboard()
     {
         return true;
     }
@@ -216,91 +229,42 @@ class Safe_service_class extends Safe_module_class
      *           
      * @return true/false
      */
-    public function can_restore(&$reason)
+    public function can_restore($info, &$reason)
     {
-        // If we're a service, and we're running no way we can restore.
-        if (Safe_service_class::STATUS_RUNNING == $this->status()) {
-            $reason = $this->description() . ' is Running';
-            return false;
+        $def = $this->property('can_restore', true);
+        if('true' === $def){
+            return true;
         }
-        return parent::can_restore($reason);
+        // Only check for 'system' and 'configuration' archive restore
+        if('system' == $info['type'] || 'configuration' == $info['type']){
+            // If we're a service, and we're running no way we can restore.
+            if (Safe_service_class::STATUS_RUNNING == $this->status()) {
+                $reason[] = $this->description() . ' is Running';
+                return false;
+            }
+        }
+        return parent::can_restore($info, $reason);
     }
-
     /**
-     * @brief 
+     * @brief Returns pid file path
      *
-     * @param[in out] $reason
+     * If run_dir is different than default, override $this->_run_dir protected 
+     * variable
      *
      * @return 
      */
-    public function pre_backup(&$reason)
+    public function pid_file()
     {
-        // Check if product script exists
-        $base = $this->node()->configuration_manager()->directory('base');
-        $script = $base.'/scripts/'.$this->name().'.backup.pre';
-        if(file_exists($script)) {
-            error_log('pre_backup - Invoking ' . $script);
-            $this->node()->execute($script, $retCode);
+        // Check if process name used as directory
+        if(file_exists($this->_run_dir.'/'.$this->_process_name)){
+            return $this->_run_dir.'/'.$this->_process_name.'/'.$this->_process_name.'.pid';
+        }else{
+            return $this->_run_dir.'/'.$this->_process_name.'.pid';
         }
-
-        return parent::pre_backup($reason);
     }
-    /**
-     * @brief 
-     *
-     * @param[in out] $reason
-     *
-     * @return 
-     */
-    public function post_backup(&$reason)
+    public function process_name()
     {
-        // Check if product script exists
-        $base = $this->node()->configuration_manager()->directory('base');
-        $script = $base.'/scripts/'.$this->name().'.backup.post';
-        if(file_exists($script)) {
-            error_log('post_backup - Invoking ' . $script);
-            $this->node()->execute($script, $retCode);
-        }
-
-        return parent::post_backup($reason);
-    }
-    /**
-     * @brief 
-     *
-     * @param[in out] $reason
-     *
-     * @return 
-     */
-    public function pre_restore(&$reason)
-    {
-        // Check if product script exists
-        $base = $this->node()->configuration_manager()->directory('base');
-        $script = $base.'/scripts/'.$this->name().'.restore.pre';
-        if(file_exists($script)) {
-            error_log('pre_restore - Invoking ' . $script);
-            $this->node()->execute($script, $retCode);
-        }
-
-        return parent::pre_restore($reason);
-    }
-    /**
-     * @brief 
-     *
-     * @param[in out] $reason
-     *
-     * @return 
-     */
-    public function post_restore(&$reason)
-    {
-        // Check if product script exists
-        $base = $this->node()->configuration_manager()->directory('base');
-        $script = $base.'/scripts/'.$this->name().'.restore.post';
-        if(file_exists($script)) {
-            error_log('post_restore - Invoking ' . $script);
-            $this->node()->execute($script, $retCode);
-        }
-
-        return parent::post_restore($reason);
+        return $this->_process_name;
     }
 }
 /* End of file safe_service_class.php */
