@@ -732,7 +732,7 @@ class Sng_config_manager extends Safe_CI_Controller
         if (!$this->upload->do_upload($file_element_name))
         {
             $status = 'error';
-            $msg = 'Upload file error!';
+            $msg = $this->upload->error_msg;
             return false;
         }
         $status = "success";
@@ -808,6 +808,13 @@ class Sng_config_manager extends Safe_CI_Controller
                     }
                     $_data['base64_encode_contents'] = base64_encode($file_data['content']);
                     $_data['file_name'] = $file_data['file_name'];
+                }else{
+                    $data['message'] = 'Upload file failed.';
+                    $data['reason'] = $file_msg;
+                    $data['message_type'] = 'alert';
+                    $data['result'] = false;
+                    echo json_encode($data);
+                    return;
                 }
             }
             // Check we can create the object (delegate to module)
@@ -819,6 +826,7 @@ class Sng_config_manager extends Safe_CI_Controller
                 $data['message_type'] = 'alert';
                 $data['result'] = false;
                 echo json_encode($data);
+                return;
             } else {
                 // Ask module to create aggregate object
                 // If 'profile-type' is specified in post, then use it instead 
